@@ -11,6 +11,7 @@ from . import test_mark_tokens
 class TestAstroid(test_mark_tokens.TestMarkTokens):
 
   is_astroid_test = True
+  astroid_version = int(astroid.__version__.split('.')[0])
   module = astroid
 
   nodes_classes = astroid_node_classes.NodeNG
@@ -27,13 +28,23 @@ class TestAstroid(test_mark_tokens.TestMarkTokens):
 
     Similar to ast.iter_fields, but for astroid and ignores context
     """
-    for field in node._astroid_fields + node._other_fields:
+    fields = node._astroid_fields + node._other_fields
+    for field in fields:
       if field == 'ctx':
         continue
+      if field == 'doc' and 'doc_node' in fields:
+        continue
       yield field, getattr(node, field)
 
   @staticmethod
   def create_asttokens(source):
     builder = astroid.builder.AstroidBuilder()
-    tree = builder.string_build(source)
+    try:
+      tree = builder.string_build(source)
+    except AttributeError as e:
+      raise AstroidTreeException(str(e))
     return ASTTokens(source, tree=tree)
+
+
+class AstroidTreeException(Exception):
+  pass
