@@ -32,11 +32,12 @@ class TestMarkTokens(unittest.TestCase):
   # the `astroid` library. The latter derives TestAstroid class from TestMarkTokens. For checks
   # that differ between them, .is_astroid_test allows to distinguish.
   is_astroid_test = False
+  astroid_version = None  # type: int | None
   module = ast
 
   def create_mark_checker(self, source, verify=True):
     atok = self.create_asttokens(source)
-    checker = tools.MarkChecker(atok, self.is_astroid_test)
+    checker = tools.MarkChecker(atok)
 
     # The last token should always be an ENDMARKER
     # None of the nodes should contain that token
@@ -140,9 +141,14 @@ b +     # line3
     tested_nodes = m.verify_all_nodes(self)
 
     exp_index = (0 if six.PY2 else 1) + (3 if self.is_astroid_test else 0)
-    # For ast on Python 3.9, slices are expressions, we handle them and test them.
-    if not self.is_astroid_test and issubclass(ast.Slice, ast.expr):
-      exp_index += 1
+    if not self.is_astroid_test:
+      # For ast on Python 3.9, slices are expressions, we handle them and test them.
+      if issubclass(ast.Slice, ast.expr):
+        exp_index += 1
+    else:
+      # Astroid v3 has some changes from v2
+      if self.astroid_version == 3:
+        exp_index += 1
     exp_tested_nodes = self.expect_tested_nodes[path][exp_index]
     self.assertEqual(tested_nodes, exp_tested_nodes)
 
@@ -151,20 +157,20 @@ b +     # line3
   # change reduces the count by a lot, it's a red flag that the test is now covering fewer nodes.
   expect_tested_nodes = {
     #                                   AST                  | Astroid
-    #                                   Py2   Py3  Py3+slice | Py2   Py3
-    'astroid/__init__.py':            ( 4,    4,   4,          4,    4,   ),
-    'astroid/absimport.py':           ( 4,    3,   3,          4,    3,   ),
-    'astroid/all.py':                 ( 21,   23,  23,         21,   23,  ),
-    'astroid/clientmodule_test.py':   ( 75,   67,  67,         69,   69,  ),
-    'astroid/descriptor_crash.py':    ( 30,   28,  28,         30,   30,  ),
-    'astroid/email.py':               ( 3,    3,   3,          1,    1,   ),
-    'astroid/format.py':              ( 64,   61,  61,         62,   62,  ),
-    'astroid/module.py':              ( 185,  174, 174,        171,  171, ),
-    'astroid/module2.py':             ( 248,  253, 255,        240,  253, ),
-    'astroid/noendingnewline.py':     ( 57,   59,  59,         57,   63,  ),
-    'astroid/notall.py':              ( 15,   17,  17,         15,   17,  ),
-    'astroid/recursion.py':           ( 6,    6,   6,          4,    4,   ),
-    'astroid/suppliermodule_test.py': ( 20,   17,  17,         18,   18,  ),
+    #                                   Py2   Py3  Py3+slice | Py2   Py3+v2 Py3+v3
+    'astroid/__init__.py':            ( 4,    4,   4,          4,    4,     4,   ),
+    'astroid/absimport.py':           ( 4,    3,   3,          4,    3,     3,   ),
+    'astroid/all.py':                 ( 21,   23,  23,         21,   23,    23,  ),
+    'astroid/clientmodule_test.py':   ( 75,   67,  67,         69,   69,    69,  ),
+    'astroid/descriptor_crash.py':    ( 30,   28,  28,         30,   30,    30,  ),
+    'astroid/email.py':               ( 3,    3,   3,          1,    1,     1,   ),
+    'astroid/format.py':              ( 64,   61,  61,         62,   62,    62,  ),
+    'astroid/module.py':              ( 185,  174, 174,        171,  171,   173, ),
+    'astroid/module2.py':             ( 248,  253, 255,        240,  253,   253, ),
+    'astroid/noendingnewline.py':     ( 57,   59,  59,         57,   63,    63,  ),
+    'astroid/notall.py':              ( 15,   17,  17,         15,   17,    17,  ),
+    'astroid/recursion.py':           ( 6,    6,   6,          4,    4,     4,   ),
+    'astroid/suppliermodule_test.py': ( 20,   17,  17,         18,   18,    18,  ),
   }
 
   # This set of methods runs verifications for the variety of syntax constructs used in the
@@ -507,6 +513,10 @@ bar = ('x y z'   # comment2
       @deco3()
       def g(x):
         pass
+
+      @deco4
+      class C:
+        pass
     """)
     m = self.create_mark_checker(source)
     # The `arguments` node has bogus positions here (and whenever there are no arguments). We
@@ -627,6 +637,8 @@ j  # not a complex number, just a name
       so it only tests all modules if the environment variable
       ASTTOKENS_SLOW_TESTS has been set.
       """
+      from .test_astroid import AstroidTreeException
+
       modules = list(sys.modules.values())
       if not os.environ.get('ASTTOKENS_SLOW_TESTS'):
         modules = modules[:20]
@@ -640,7 +652,7 @@ j  # not a complex number, just a name
 
         try:
           filename = inspect.getsourcefile(module)
-        except TypeError:
+        except Exception:  # some modules raise weird errors
           continue
 
         if not filename:
@@ -657,20 +669,21 @@ j  # not a complex number, just a name
         if self.is_astroid_test and (
             # Astroid fails with a syntax error if a type comment is on its own line
             re.search(r'^\s*# type: ', source, re.MULTILINE)
-            # Astroid can fail on this file, specifically raising an exception at this line of code:
-            #     lambda node: node.name == "NamedTuple" and node.parent.name == "typing"
-            # with the error:
-            #     AttributeError: 'If' object has no attribute 'name'
-            # See https://github.com/gristlabs/asttokens/runs/7602147792
-            # I think the code that causes the problem is:
-            #     if sys.version_info >= (3, 11):
-            #         NamedTuple = typing.NamedTuple
-            or filename.endswith("typing_extensions.py")
         ):
           print('Skipping', filename)
           continue
 
-        self.create_mark_checker(source)
+        try:
+          self.create_mark_checker(source)
+        except AstroidTreeException:
+          # Astroid sometimes fails with errors like:
+          #     AttributeError: 'TreeRebuilder' object has no attribute 'visit_typealias'
+          # See https://github.com/gristlabs/asttokens/actions/runs/6015907789/job/16318767911?pr=110
+          # Should be fixed in the next astroid release:
+          #     https://github.com/pylint-dev/pylint/issues/8782#issuecomment-1669967220
+          # Note that this exception is raised before asttokens is even involved,
+          # it's purely an astroid bug that we can safely ignore.
+          continue
 
   if six.PY3:
     def test_dict_merge(self):
